@@ -562,8 +562,9 @@ Foreman::AccessControl.map do |permission_set|
       :users => [:new, :create],
       :"api/v2/users" => [:create]
     map.permission :edit_users,
-      :users => [:edit, :update],
-      :"api/v2/users" => [:update]
+      :users => [:edit, :update, :invalidate_jwt, :invalidate_jwt_for_all_users],
+      :"api/v2/users" => [:update],
+      :"api/v2/registration_tokens" => [:invalidate_jwt_tokens, :invalidate_jwt]
     map.permission :destroy_users,
       :users => [:destroy],
       :"api/v2/users" => [:destroy]
