@@ -75,6 +75,21 @@ class UnattendedControllerTest < ActionController::TestCase
       assert_response :success
     end
 
+    test "should get a kickstart when pure IPv6 address is used" do
+      ptable = Ptable.find_by(name: 'default')
+      @ipv6_host = FactoryBot.create(:host, :managed, :with_ipv6, :build => true,
+                                     :operatingsystem => operatingsystems(:redhat),
+                                     :ptable => ptable,
+                                     :medium => media(:one),
+                                     :architecture => architectures(:x86_64),
+                                     :organization => @org,
+                                     :location => @loc)
+      @request.env["HTTP_X_FORWARDED_FOR"] = @ipv6_host.ip6
+      @request.env["REMOTE_ADDR"] = "::1"
+      get :host_template, params: { :kind => 'provision' }
+      assert_response :success
+    end
+
     test "should set @static when requested" do
       Setting[:safemode_render] = false
       @request.env["HTTP_X_RHN_PROVISIONING_MAC_0"] = "eth0 #{@rh_host.mac}"
@@ -373,6 +388,16 @@ class UnattendedControllerTest < ActionController::TestCase
       refute nic.build
     end
 
+    test "should accept built notifications over ipv6 and store the address" do
+      nic6 = '2001:db8::1234'
+      Setting[:update_ip_from_built_request] = true
+      @request.env["REMOTE_ADDR"] = nic6
+      post :built, params: { mac: @ub_host.primary_interface.mac }
+      assert_response :created
+      @ub_host.reload
+      assert_equal nic6, @ub_host.primary_interface.ip6
+    end
+
     test "should accept failed notifications" do
       @request.env["REMOTE_ADDR"] = @ub_host.ip
       post :failed
