@@ -1,7 +1,7 @@
 import React, { useState } from 'react';
 import PropTypes from 'prop-types';
 import {
-  TableComposable,
+  Table as PFTable,
   Thead,
   Tr,
   Th,
@@ -40,6 +40,7 @@ export const Table = ({
   idColumn,
   children,
   bottomPagination,
+  childrenOutsideTbody, // Expandable table rows are each a Tbody so they cant be inside the Tbody
 }) => {
   const onPagination = newPagination => {
     setParams({ ...params, ...newPagination });
@@ -85,17 +86,23 @@ export const Table = ({
     id,
     name,
     ...item
-  }) =>
-    [
+  }) => {
+    const extendActions =
+      (getActions && getActions({ id, name, canDelete, canEdit, ...item })) ??
+      [];
+
+    return [
       isDeleteable && {
         title: __('Delete'),
         onClick: () => onDeleteClick({ id, name }),
-        isDisabled: !canDelete,
+        isAriaDisabled: !canDelete,
       },
-      ...((getActions &&
-        getActions({ id, name, canDelete, canEdit, ...item })) ??
-        []),
+      ...extendActions.map(action => ({
+        ...action,
+        isAriaDisabled: action.isDisabled,
+      })),
     ].filter(Boolean);
+  };
   const RowSelectTd = rowSelectTd;
   return (
     <>
@@ -106,10 +113,20 @@ export const Table = ({
         url={url}
         refreshData={refreshData}
       />
-      <TableComposable variant="compact" ouiaId="table" isStriped>
+      <PFTable
+        variant="compact"
+        ouiaId="table"
+        isStriped
+        isExpandable={childrenOutsideTbody}
+      >
         <Thead>
           <Tr ouiaId="table-header">
-            {showCheckboxes && <Th key="checkbox-th" />}
+            {showCheckboxes && (
+              <Th aria-label="checkbox-header" key="checkbox-th" />
+            )}
+            {childrenOutsideTbody && (
+              <Th aria-label="expansion-carat" key="expansion-carat" />
+            )}
             {columnNamesKeys.map(k => (
               <Th
                 key={k}
@@ -117,12 +134,14 @@ export const Table = ({
                   Object.values(columnsToSortParams).includes(k) &&
                   pfSortParams(keysToColumnNames[k])
                 }
+                aria-label={keysToColumnNames[k]}
               >
                 {keysToColumnNames[k]}
               </Th>
             ))}
           </Tr>
         </Thead>
+        {childrenOutsideTbody ? children : null}
         <Tbody>
           {isPending && results.length === 0 && (
             <Tr ouiaId="table-loading">
@@ -160,36 +179,41 @@ export const Table = ({
               </Td>
             </Tr>
           )}
-          {children ||
-            results.map((result, rowIndex) => {
-              const rowActions = actions(result);
-              return (
-                <Tr key={rowIndex} ouiaId={`table-row-${rowIndex}`} isHoverable>
-                  {showCheckboxes && (
-                    <RowSelectTd
-                      rowData={result}
-                      selectOne={selectOne}
-                      isSelected={isSelected}
-                      idColumnName={idColumn}
-                    />
-                  )}
-                  {columnNamesKeys.map(k => (
-                    <Td key={k} dataLabel={keysToColumnNames[k]}>
-                      {columns[k].wrapper
-                        ? columns[k].wrapper(result)
-                        : result[k]}
+          {!childrenOutsideTbody &&
+            (children ||
+              results.map((result, rowIndex) => {
+                const rowActions = actions(result);
+                return (
+                  <Tr
+                    key={rowIndex}
+                    ouiaId={`table-row-${rowIndex}`}
+                    isClickable
+                  >
+                    {showCheckboxes && (
+                      <RowSelectTd
+                        rowData={result}
+                        selectOne={selectOne}
+                        isSelected={isSelected}
+                        idColumnName={idColumn}
+                      />
+                    )}
+                    {columnNamesKeys.map(k => (
+                      <Td key={k} dataLabel={keysToColumnNames[k]}>
+                        {columns[k].wrapper
+                          ? columns[k].wrapper(result)
+                          : result[k]}
+                      </Td>
+                    ))}
+                    <Td isActionCell>
+                      {rowActions.length ? (
+                        <ActionsColumn items={rowActions} />
+                      ) : null}
                     </Td>
-                  ))}
-                  <Td isActionCell>
-                    {rowActions.length ? (
-                      <ActionsColumn items={rowActions} />
-                    ) : null}
-                  </Td>
-                </Tr>
-              );
-            })}
+                  </Tr>
+                );
+              }))}
         </Tbody>
-      </TableComposable>
+      </PFTable>
       {results.length > 0 && !errorMessage && !emptyMessage && bottomPagination}
     </>
   );
@@ -222,6 +246,7 @@ Table.propTypes = {
   isSelected: PropTypes.func,
   showCheckboxes: PropTypes.bool,
   bottomPagination: PropTypes.node,
+  childrenOutsideTbody: PropTypes.bool,
 };
 
 Table.defaultProps = {
@@ -241,4 +266,5 @@ Table.defaultProps = {
   isSelected: noop,
   showCheckboxes: false,
   bottomPagination: null,
+  childrenOutsideTbody: false,
 };
